@@ -278,19 +278,35 @@ class PhysioData(object):
             json_fName = json_fName[:-len(myStr)] if json_fName.endswith( myStr ) else json_fName
         json_fName = json_fName + '_physio.json'
 
-        with open( json_fName, 'w') as f:
-            json.dump({
-                "SamplingFrequency": self.signals[0].samples_per_second,
-                "StartTime": self.signals[0].t_start(),
-                "Columns": [item.label for item in self.signals],
-                **{            # this syntax allows us to add the elements of this dictionary to the one we are creating
-                    item.label: {
-                        "Units": item.units
+        if not hasattr(self, 'RecordedEye'):
+            with open( json_fName, 'w') as f:
+                json.dump({
+                    "SamplingFrequency": self.signals[0].samples_per_second,
+                    "StartTime": self.signals[0].t_start(),
+                    "Columns": [item.label for item in self.signals],
+                    **{            # this syntax allows us to add the elements of this dictionary to the one we are creating
+                        item.label: {
+                            "Units": item.units
+                        }
+                        for item in self.signals if item.units != ""
                     }
-                    for item in self.signals if item.units != ""
-                }
-            }, f, sort_keys = True, indent = 4, ensure_ascii = False)
-            f.write('\n')
+                }, f, sort_keys = True, indent = 4, ensure_ascii = False)
+                f.write('\n')
+        else: # Eyetracking data case
+            with open( json_fName, 'w') as f:
+                json.dump({
+                    "SamplingFrequency": self.signals[0].samples_per_second,
+                    "StartTime": self.signals[0].t_start(),
+                    "RecordedEye": self.RecordedEye,
+                    "Columns": [item.label for item in self.signals],
+                    **{           # this syntax allows us to add the elements of this dictionary to the one we are creating
+                        item.label: {
+                          "Units": item.units
+                        }
+                        for item in self.signals if item.units != ""
+                    }
+                }, f, sort_keys = True, indent = 4, ensure_ascii = False)
+                f.write('\n')
 
     def save_bids_data(self, data_fName):
         """
@@ -312,8 +328,12 @@ class PhysioData(object):
         data_fName = data_fName + '_physio.tsv.gz'
 
         # Save the data:
-        # Format: 4 decimals in general, unsigned integer if 'trigger':
-        myFmt=['% 1d' if item.label == 'trigger' else '%.4f' for item in self.signals]
+        if not hasattr(self, 'RecordedEye'):
+            # Format: 4 decimals in general, unsigned integer if 'trigger':
+            myFmt=['% 1d' if item.label == 'trigger' else '%.4f' for item in self.signals]
+        else: # Eyetracking data case
+            myFmt=['% d' if item.label in {'trigger','fixation', 'saccade', 'blink', 'samples'} else '%.1f' for item in self.signals]
+        
         np.savetxt(
             data_fName,
             np.transpose( [item.signal for item in self.signals] ),
@@ -346,8 +366,15 @@ class PhysioData(object):
                                )
 
         print('')
-
-        if len(unique_sr_ts) == 1:
+        
+        if hasattr(self, 'RecordedEye'):
+            #eyetracking case
+            rec_fName = '{0}_recording-eyetracking_physio'.format(self.bidsPrefix)
+            print('Saving eyetracking physio data')
+            self.save_bids_json(rec_fName)
+            self.save_bids_data(rec_fName)
+                
+        elif len(unique_sr_ts) == 1:
             # All the physio signals have the same sampling rate and t_start, so
             #   there will be just one _physio file and we don't need to add "_recording-"
 
@@ -505,8 +532,14 @@ class PhysioData(object):
         for idx, [sr,ts] in enumerate( unique_sr_ts ):
 
             ###   Get filename   ###
-
-            if len(unique_sr_ts) == 1:
+            if hasattr(self, 'RecordedEye'):
+                #eyetracking case
+                rec_fName = '{0}_recording-eyetracking_physio'.format(self.bidsPrefix)
+                print('Saving eyetracking physio data')
+                self.save_bids_json(rec_fName)
+                self.save_bids_data(rec_fName)
+            
+            elif len(unique_sr_ts) == 1:
                 # All the physio signals (except, potentially, the "trigger") have the
                 #   same sampling rate and t_start, there will be just one _physio file
                 #   and we don't need to add "_recording-":
@@ -545,6 +578,10 @@ class PhysioData(object):
 
                 # Append this new signal to "physiodata_group":
                 physiodata_group.append_signal( trigger_for_this_group )
+                    
+            # If the original PhysioData object had a "RecordedEye" attribute, add it to the new PhysioData object
+            if hasattr(self, 'RecordedEye'):
+                setattr(physiodata_group, 'RecordedEye', self.RecordedEye)
 
             ###   Save the data   ###
 
